#!/bin/sh

# $SCRIPTDIR/cluster-maintenance.sh
# 
# Script to deal with any hung processes, or other updates. Completely 
# restart qmail and all important processes every X hours...
# 						     "just in case" :)
# 
# Japheth Cleaver - cleaver@rohan.sdsu.edu
# 

# Load this installation's configuration
if [ -z "$VPOPMAILHOME" ]; then
   if [ -r /etc/sysconfig/vpopmail ]; then
	. /etc/sysconfig/vpopmail
   else
	echo "$0: Unable to read /etc/sysconfig/vpopmail"
	exit 1
   fi
fi

if [ -z "$IS_CLUSTER" -o -n "$IS_MASTER" ]; then 
	echo "This script should NOT be run on the master server!" 
	echo "Edit /etc/sysconfig/vpopmail on `uname -n` or stop running $0"
	exit 1
fi

if [ ! -x "$SCRIPTDIR/cluster-stop.sh" -o ! -x "$SCRIPTDIR/cluster-start.sh" ]; then
	echo "Unable to find cluster-stop and cluster-start scripts in $SCRIPTDIR"
	exit 1
fi


#######################################################################

if [ "$1" = "svscan" ]; then
   /sbin/service svscan stop
fi

. "$SCRIPTDIR/cluster-stop.sh"

#######################################################################
# 
# This would be a good spot to put your custom maintenance stuff.
# Copy over configs, do delayed installs, whatever you want...

# Sync date... important for a mail server!
  rdate -s ntp.redwire.net

# Run some upgrades...
  # rpm -U /vpopmail/mailinstall/rpmbuild/RPMS/i386/up-imapproxy-1.2.4-1.i386.rpm
  # cpan Crypt::OpenSSL::Bignum # Crypt::PasswdMD5

# Clear out old sockets, temporary attachments, and other things
  find /dev/shm/* -amin +30 -print0 | xargs -r0 rm -fR


# Distribute some files
  if [ ! -f /etc/rc.d/init.d/spamassassin ] ; then
     install -m 755 $CONFIGDIR/spamassassin/spamassassin.initrdscript /etc/rc.d/init.d/spamassassin
     /sbin/chkconfig --add spamassassin
  fi

# Chown clamav files
  chown -R clamav /var/log/clamav

# Check for a courier-imap upgrade that might have enabled pop3/pop3-ssl
 # - We use qmail-pop3d, not courier's... so that could cause problems
 #   if both try to run...
 # 
 if [ -r "$CONFIGDIR/courier-imap_etc-imapd" ]; then
	cp -fp "$CONFIGDIR/courier-imap_etc-imapd" /usr/lib/courier-imap/etc/imapd
 fi
 if [ -f /usr/lib/courier-imap/etc/pop3d ] ; then
	mv -f /usr/lib/courier-imap/etc/pop3d /usr/lib/courier-imap/etc/pop3d.old
 fi
 if [ -f /usr/lib/courier-imap/etc/pop3d-ssl ] ; then
	mv -f /usr/lib/courier-imap/etc/pop3d-ssl /usr/lib/courier-imap/etc/pop3d-ssl.old
 fi
 if [ ! -L /usr/lib/courier-imap/share/imapd.pem ]; then
	rm -f /usr/lib/courier-imap/share/imapd.pem && \
	ln -s /etc/qmail/control/imapd-ssl.pem /usr/lib/courier-imap/share/imapd.pem
 fi
 if [ ! -L /usr/lib/courier-imap/share/pop3d.pem ]; then
	rm -f /usr/lib/courier-imap/share/pop3d.pem && \
	ln -s /etc/qmail/control/pop3d-ssl.pem /usr/lib/courier-imap/share/pop3d.pem
 fi

 # This should not be run on clients now because we're using a shared
 # directory for greylisting...
 # cp -fp $SHAREDDIR/mailinstall/sa311/* /usr/lib/perl5/site_perl/5.8.8/Mail/SpamAssassin/

#######################################################################

 # Run our updates... the cluster-update script takes care of syncing
 # between the master server and here. 'NORELOAD' prevents it from
 # trying to reload qmail-smtpd or anything else, since none of them
 # are running at this point.

 export NORELOAD=NORELOAD
 [ -r "$SCRIPTDIR/cluster-update.sh" ] && . $SCRIPTDIR/cluster-update.sh
 /usr/sbin/simscanmk -g >/dev/null

 cp -fp "$CONFIGDIR/sysconfig-hobbit-client" /etc/sysconfig/hobbit-client


#######################################################################

echo "Starting services back up..."
sleep 2

. "$SCRIPTDIR/cluster-start.sh"

if [ "$1" = "svscan" ]; then
   /sbin/service svscan start
fi

#######################################################################

echo "Performing reload..."
sleep 1

/sbin/service qmail reload
