#!/bin/sh

# $SCRIPTDIR/cluster-update.sh
#
# Update the "important" files from a central shared NFS mount to
# the appropriate locations on a cluster machine
# 
# This runs every few minutes on every cluster machine.
# 
# Japheth Cleaver - cleaver@redwire.net
#

# Load this installation's configuration
if [ -z "$VPOPMAILHOME" ]; then
   if [ -r /etc/sysconfig/vpopmail ]; then
	. /etc/sysconfig/vpopmail
   else
	echo "$0: Unable to read /etc/sysconfig/vpopmail"
	exit 1
   fi
fi

if [ ! -e "$CONFIGDIR" ]; then
   echo "Error: $CONFIGDIR doesn't seem to exist!" >&2
   exit 1
fi

if [ -z "$IS_CLUSTER" -o -n "$IS_MASTER" ]; then  
	echo "This script should NOT be run on the master server!"
	echo "Edit /etc/sysconfig/vpopmail on `uname -n` or stop running $0"
	exit 1
fi


# Use any value as its arg to prevent an actual reload of the processes
# Allows this script to be run when we know qmail isn't running
[ -z "$NORELOAD" ] && NORELOAD="$1"

pushd "$CONFIGDIR" >/dev/null

  cp -pf httpd_welcome.conf	/etc/httpd/conf.d/welcome.conf
  cp -pf freshclam.conf		/etc/freshclam.conf
  cp -pf clamd.conf		/etc/clamd.conf
  cp -pf dspam.conf		/etc/dspam.conf
  cp -pf imapproxy.conf		/etc/imapproxy.conf
  cp -pf tcprules_qmail-pop3d	/etc/tcprules.d/qmail-pop3d
  cp -pf tcprules_qmail-smtpd	/etc/tcprules.d/qmail-smtpd
  cp -pf resolv.conf		/etc/resolv.conf
  cp -pf hosts			/etc/hosts

  # Things which should be moved atomically
  cp -pf etc-sudoers		/etc/sudoers.tmp
  cp -pf vpopmail-mysql		/etc/vpopmail/vpopmail.mysql.tmp
  cp -pf virus_replacement_text	/etc/vpopmail/virus-replacement.msg.tmp

  chmod 444			/etc/vpopmail/vpopmail.mysql.tmp

popd >/dev/null


# Now, move from the temporary locations over to the real ones
 for I in /etc/sudoers /etc/vpopmail/virus-replacement.msg /etc/vpopmail/vpopmail.mysql
 do
    mv -f "$I.tmp" "$I"
 done

# Copy over our /etc/qmail/control files...
  pushd "$CONTROLDIR" >/dev/null
     for THIS in `ls | grep -v .pem`
     do
	cp -pf "$THIS" "/etc/qmail/control/$THIS.tmp"
	mv -f "/etc/qmail/control/$THIS.tmp" "/etc/qmail/control/$THIS"
     done
  popd >/dev/null


# Move users/assign to the right spot...
  mv -f /etc/qmail/control/assign /etc/qmail/users/assign

# Copy over .pem certificate files (separate permissions)
  install -m 600 -o qmaild -g nofiles $CONTROLDIR/pop3d-ssl.pem /etc/qmail/control/
  install -m 600 -o qmaild -g nofiles $CONTROLDIR/smtpd-ssl.pem /etc/qmail/control/
  install -m 640 -o root -g qmail     $CONTROLDIR/imapd-ssl.pem /etc/qmail/control/
  
# Squirrelmail configs
  cp -pf $CONFIGDIR/squirrelmail/*.php	/etc/squirrelmail/

  for THIS in `find $CONFIGDIR/squirrelmail/plugins/*/*`; do
	DEST=`echo $THIS | perl -pe "s#$CONFIGDIR#/etc#"`
	cp -pf "$THIS" "$DEST"  
  done


# Restart spamassassin/vprocessmail if things have changed with SA
  if [ "$CONFIGDIR/spamassassin/local.cf" -nt "/etc/mail/spamassassin/local.cf" ]; then
     cp -pf $CONFIGDIR/spamassassin/*.pre	/etc/mail/spamassassin/
     cp -pf $CONFIGDIR/spamassassin/*.cf	/etc/mail/spamassassin/
     cp -pf $CONFIGDIR/spamassassin/*.words	/etc/mail/spamassassin/
     cp -pf $CONFIGDIR/sysconfig-spamassassin	/etc/sysconfig/spamassassin
     /sbin/service svscan restart vprocessmail
     /sbin/service spamassassin restart
  fi

# Determine if our iptables config changed; if so, reload
  if [ "$CONFIGDIR/sysconfig-iptables" -nt "/etc/sysconfig/iptables" ]; then
     cp -fp $CONFIGDIR/sysconfig-iptables /etc/sysconfig/iptables
     /sbin/service iptables condrestart
  fi

  if [ "$CONFIGDIR/badmailfromdomains" -nt "/etc/qmail/control/badmailfromdomains" ]; then
     cp -fp $CONFIGDIR/badmailfromdomains /etc/qmail/control/badmailfromdomains
     killall speedy_backend
  fi

  rm -f /var/lib/clamav/\*.cvd

  if [ "$CONFIGDIR/MSRBL-Images.hdb" -nt "/var/lib/clamav/MSRBL-Images.hdb" ]; then
     cp -fp $CONFIGDIR/MSRBL-Images.hdb /var/lib/clamav/MSRBL-Images.hdb
     CLAMUPDATE=1
  fi

  NDBS=`cd $CONFIGDIR; ls *ndb`
  if [ "$NDBS" ] ; then
   for THIS in $NDBS
   do
     if [ "$CONFIGDIR/$THIS" -nt "/var/lib/clamav/$THIS" ]; then
	cp -fp $CONFIGDIR/$THIS /var/lib/clamav/$THIS
	CLAMUPDATE=1
     fi
   done
  fi

  # If clamd isn't running for some reason, restart it
  [ -n "$NORELOAD" ] || /sbin/service clamd status >/dev/null || CLAMRESTART=1

  if [ ! -z "$CLAMUPDATE" ] ; then
     /sbin/service freshclam stop
     /sbin/service clamd stop
     killall clamd freshclam >/dev/null
     CLAMRESTART="1"

     chown -R clamav:clamav /var/lib/clamav
     chmod -R o+rx /var/lib/clamav
  fi

  if [ "$CLAMRESTART" -a ! -n "$NORELOAD" ]; then
	/sbin/service clamd start
     	/sbin/service freshclam start
  fi


##########################################################################
# Do some other software distribution
##########################################################################

# Updates to things which require restarting vprocessmail

# Only distribute domainkeys on our outgoing smtp server! We don't DKIM sign anything else
  # cp -pfR $CONFIGDIR/domainkeys/* /etc/domainkeys/

# Distribute packages from distros
  # yum -y --enablerepo=crash-hat update

# Kill any hung gocr processes
  ps ax | grep gocr | grep -v readproctitle | sort -nr -k 4 | grep -v 0:0 | awk '{print $1}' | xargs -r kill -TERM


# Enable/Disable final delivery across the board...
  # perl -pi -e 's/^#export/export/' /usr/sbin/vdelivermail	# enable
  # perl -pi -e 's/^export/#export/' /usr/sbin/vdelivermail	# disable


##########################################################################
# Rehash qmail after updating all of our files...
##########################################################################

  [ -n "$NORELOAD" ] || /sbin/service qmail reload >/dev/null
  /usr/sbin/simscanmk >/dev/null

