#!/bin/sh

# $SCRIPTDIR/master-maintenance.sh
# 
# Script to update long-running systems, and other general activity
# 
# Japheth Cleaver - cleaver@rohan.sdsu.edu
# 

# Load this installation's configuration
if [ -z "$VPOPMAILHOME" ]; then
   if [ -r /etc/sysconfig/vpopmail ]; then
	. /etc/sysconfig/vpopmail
   else
	echo "$0: Unable to read /etc/sysconfig/vpopmail"
	exit 1
   fi
fi

if [ -n "$IS_CLUSTER" -o -z "$IS_MASTER" ]; then 
	echo "This script should ONLY be run on the master server!" 
	echo "Edit /etc/sysconfig/vpopmail on `uname -n` or stop running $0"
	exit 1
fi


#######################################################################

#######################################################################
# 
# This would be a good spot to put your custom maintenance stuff.
# Copy over configs, do delayed installs, whatever you want...

# Sync date... important for a mail server!
 rdate -s time.sdsc.edu


# Distribute some files

# Get potentially updated version of MSRBL-Images.hdb
 wget -nv -N -O "$CONFIGDIR/MSRBL-Images.hdb.tmp" http://download.mirror.msrbl.com/MSRBL-Images.hdb
 if [ "$CONFIGDIR/MSRBL-Images.hdb.tmp" -nt "$CONFIGDIR/MSRBL-Images.hdb" ]; then
    if [ `wc -l "$CONFIGDIR/MSRBL-Images.hdb.tmp" | awk '{print $1}'` -ne 0 ]; then
        # Remove MSRBL images with < 880 hits on them -- prevent false positives (or try to)
	#  sort -t : -k 2 -n "$CONFIGDIR/MSRBL-Images.hdb.tmp"  | grep --after-context=99999999 ':88.:' | grep -vf "$CONFIGDIR/MSRBL-falsepos-list" > "$CONFIGDIR/MSRBL-Images.hdb"

	[ ! -e "$CONFIGDIR/MSRBL-falsepos-list" ] && touch "$CONFIGDIR/MSRBL-falsepos-list"
	grep -vf "$CONFIGDIR/MSRBL-falsepos-list" "$CONFIGDIR/MSRBL-Images.hdb.tmp" > "$CONFIGDIR/MSRBL-Images.hdb"
	cp -fp "$CONFIGDIR/MSRBL-Images.hdb" "/var/lib/clamav/MSRBL-Images.hdb"
    fi
 fi

 wget -nv -N -O "$CONFIGDIR/phish.ndb.gz" http://www.sanesecurity.com/clamav/phishsigs/phish.ndb.gz
 wget -nv -N -O "$CONFIGDIR/scam.ndb.gz" http://www.sanesecurity.com/clamav/phishsigs/scam.ndb.gz

 cp -fp "$CONFIGDIR/phish.ndb.gz" "$CONFIGDIR/phish.ndb.tmp.gz"
 cp -fp "$CONFIGDIR/scam.ndb.gz" "$CONFIGDIR/scam.ndb.tmp.gz"

 gunzip -fN "$CONFIGDIR/phish.ndb.tmp.gz"
 gunzip -fN "$CONFIGDIR/scam.ndb.tmp.gz"
 
 wget -nv -N -O "$CONFIGDIR/badmailfromdomains.tmp" http://www.sa-blacklist.stearns.org/sa-blacklist/sa-blacklist.current.at-domains
 if [ "$CONFIGDIR/badmailfromdomains.tmp" -nt "$CONFIGDIR/badmailfromdomains" ]; then
	tr -d '@' > "$CONFIGDIR/badmailfromdomains" < "$CONFIGDIR/badmailfromdomains.tmp"
	touch -r "$CONFIGDIR/badmailfromdomains.tmp" "$CONFIGDIR/badmailfromdomains"
 fi


# Check for a courier-imap upgrade that might have enabled pop3/pop3-ssl
 # - We use qmail-pop3d, not courier's... so that could cause problems
 #   if both try to run...
 # 
 if [ -r "$CONFIGDIR/courier-imap_etc-imapd" ]; then
	cp -fp "$CONFIGDIR/courier-imap_etc-imapd" /usr/lib/courier-imap/etc/imapd
 fi
 if [ -f /usr/lib/courier-imap/etc/pop3d ] ; then
	mv -f /usr/lib/courier-imap/etc/pop3d /usr/lib/courier-imap/etc/pop3d.old
 fi
 if [ -f /usr/lib/courier-imap/etc/pop3d-ssl ] ; then
	mv -f /usr/lib/courier-imap/etc/pop3d-ssl /usr/lib/courier-imap/etc/pop3d-ssl.old
 fi
 if [ ! -L /usr/lib/courier-imap/share/imapd.pem ]; then
	rm -f /usr/lib/courier-imap/share/imapd.pem && \
	ln -s /etc/qmail/control/imapd-ssl.pem /usr/lib/courier-imap/share/imapd.pem
 fi
 if [ ! -L /usr/lib/courier-imap/share/pop3d.pem ]; then
	rm -f /usr/lib/courier-imap/share/pop3d.pem && \
	ln -s /etc/qmail/control/pop3d-ssl.pem /usr/lib/courier-imap/share/pop3d.pem
 fi

 # This should not be run on clients now because we're using a shared
 # directory for greylisting...
 # cp -fp $SHAREDDIR/mailinstall/sa311/* /usr/lib/perl5/site_perl/5.8.8/Mail/SpamAssassin/


#######################################################################

 # Run our updates... the cluster-update script takes care of syncing
 # between the master server and here. 'NORELOAD' prevents it from
 # trying to reload qmail-smtpd or anything else, since none of them
 # are running at this point.

 export NORELOAD=NORELOAD

 
 /sbin/service spamassassin restart
 /sbin/service clamd restart
 /sbin/service freshclam restart

 # Get new clamav database versions...
 /sbin/service qmail reload

